--	1
--	Intersect vs Inner Join
--	Facility Fines with Library Fines
select STUDENT_ID
from	FACILITY_FINES
intersect 
select STUDENT_ID
from	LIBRARY_FINES

--	Inner join to find Library fines
SELECT	FF.STUDENT_ID
from	FACILITY_FINES as FF
		inner join LIBRARY_FINES as LF
			on FF.STUDENT_ID = LF.STUDENT_ID

--	2
--	Intersect vs Inner Join
--	Parking Fines with Library Fines
select STUDENT_ID
from	PARKING_FINES
intersect 
select STUDENT_ID
from	LIBRARY_FINES

--	Inner join to find students with 
--	library and parking fines
SELECT	PF.STUDENT_ID
from	PARKING_FINES as PF
		inner join LIBRARY_FINES as LF
			on PF.STUDENT_ID = LF.STUDENT_ID
			
--	3
-- Insert some more parking fines			
insert into PARKING_FINES
values (1000,10)
	,  (1001,10)
	,  (1002,10)
	,  (1004,10)

--	4
--	Intersect vs Inner Join Round 2
--	More Parking Fines with Library Fines
select STUDENT_ID
from	PARKING_FINES
intersect 
select STUDENT_ID
from	LIBRARY_FINES

--	Inner join to find students with 
--	library and parking fines
SELECT	PF.STUDENT_ID
from	PARKING_FINES as PF
		inner join LIBRARY_FINES as LF
			on PF.STUDENT_ID = LF.STUDENT_ID

--	5
--	INTERSECT vs IN
--	Find students that have Facility Fines 
--	and also have Library Fines
select	STUDENT_ID
from	FACILITY_FINES
INTERSECT
select	STUDENT_ID
from	LIBRARY_FINES

--	Try to emulate INTERSECT using IN
SELECT	FF.STUDENT_ID
from	FACILITY_FINES as FF
where	FF.STUDENT_ID in (
			select	LF.STUDENT_ID
			from	LIBRARY_FINES as LF
		)
		
--	6
--	INTERSECT vs EXISTS
--	Find students that have Facility Fines 
--	and also have Library Fines
select	STUDENT_ID
from	FACILITY_FINES
INTERSECT
select	STUDENT_ID
from	LIBRARY_FINES

--	Try with EXISTS
SELECT	FF.STUDENT_ID
from	FACILITY_FINES as FF
where	 EXISTS (
			select	1
			from	LIBRARY_FINES as LF
			where	FF.STUDENT_ID = LF.STUDENT_ID
		)		

--	Testing Except

--	7
--	Except vs Left [Outer] Join?
--	Find students that have Facility Fines 
--	but do not have Library Fines
select	STUDENT_ID
from	FACILITY_FINES
EXCEPT
select	STUDENT_ID
from	LIBRARY_FINES

--	Try LEFT JOIN 
SELECT	FF.STUDENT_ID
from	FACILITY_FINES as FF
		left join LIBRARY_FINES as LF
			on FF.STUDENT_ID = LF.STUDENT_ID

--	Try LEFT OUTER JOIN
SELECT	FF.STUDENT_ID
from	FACILITY_FINES as FF
		left outer join LIBRARY_FINES as LF
			on FF.STUDENT_ID = LF.STUDENT_ID

--	Not what we are looking for

--	8
--	EXCEPT vs NOT IN
--	Find students that have Facility Fines 
--	but do not have Library Fines
select	STUDENT_ID
from	FACILITY_FINES
EXCEPT
select	STUDENT_ID
from	LIBRARY_FINES

--	Try to emulate EXCEPT using NOT IN
SELECT	FF.STUDENT_ID
from	FACILITY_FINES as FF
where	FF.STUDENT_ID not in (
			select	LF.STUDENT_ID
			from	LIBRARY_FINES as LF
		)

--	9
--	EXCEPT vs NOT EXISTS
--	Find students that have Facility Fines 
--	but do not have Library Fines
select	STUDENT_ID
from	FACILITY_FINES
EXCEPT
select	STUDENT_ID
from	LIBRARY_FINES

--	Try with NOT EXISTS
SELECT	FF.STUDENT_ID
from	FACILITY_FINES as FF
where	not exists (
			select	1
			from	LIBRARY_FINES as LF
			where	FF.STUDENT_ID = LF.STUDENT_ID
		)